# EntryReputation

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**highlights** | [**FieldTermLocationMap**](FieldTermLocationMap.md) |  | [optional] 
**reputations_data** | [**list[ReputationData]**](ReputationData.md) |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


